summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/smpppdcs/iconnector.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/plugins/smpppdcs/iconnector.h')
-rw-r--r--kopete/plugins/smpppdcs/iconnector.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/plugins/smpppdcs/iconnector.h b/kopete/plugins/smpppdcs/iconnector.h
index ab63ec71..c4846862 100644
--- a/kopete/plugins/smpppdcs/iconnector.h
+++ b/kopete/plugins/smpppdcs/iconnector.h
@@ -37,9 +37,9 @@ public:
* This method needs to get reimplemented at classes which implement
* this interface.
*
* @param newtqStatus the status of the internet connection, <code>TRUE</code> if there is a connection, otherwise <code>FALSE</code>
*/
- virtual void setConnectedtqStatus(bool newtqStatus) = 0;
+ virtual void setConnectedStatus(bool newStatus) = 0;
};
#endif
@@ -37,9 +37,9 @@ public:
* this interface.
*
- * @param newtqStatus the status of the internet connection, <code>TRUE</code> if there is a connection, otherwise <code>FALSE</code>
+ * @param newStatus the status of the internet connection, <code>TRUE</code> if there is a connection, otherwise <code>FALSE</code>
*/